@@ -1,20 +1,20 @@
-from rgd import utility
-
-from .. import models
-from .base import ImageMetaSerializer, ImageSerializer, ImageSetSerializer
+from .base import (
+    ImageMetaSerializer,
+    ImageSerializer,
+    ImageSetSerializer,
+    ImageSetSpatialSerializer,
+)
 from .processed import ProcessedImageGroupSerializer, ProcessedImageSerializer
 from .raster import RasterMetaSerializer, RasterSerializer
-from .stac import STACRasterSerializer
-
-utility.make_serializers(globals(), models)
 
 __all__ = [
     'ImageSerializer',
     'ImageMetaSerializer',
     'ImageSetSerializer',
+    'ImageSetSpatialSerializer',
     'ProcessedImageGroupSerializer',
     'ProcessedImageSerializer',
     'RasterMetaSerializer',
     'RasterSerializer',
-    'STACRasterSerializer',
+    'RegionImageSerializer',
 ]
