@@ -34,6 +34,11 @@ urlpatterns = [
         views.RasterDetailView.as_view(),
         name=models.RasterMeta.detail_view_name,
     ),
+    path(
+        'rgd_imagery/image_set/',
+        views.ImageSetListView.as_view(),
+        name='image-sets',
+    ),
     path(
         'rgd_imagery/image_set/<int:pk>/',
         views.ImageSetDetailView.as_view(),
