@@ -4,7 +4,7 @@ import pytest
 @pytest.mark.django_db(transaction=True)
 def test_metadata(admin_api_client, geotiff_image_entry):
     response = admin_api_client.get(
-        f'/api/rgd_imagery/tiles/{geotiff_image_entry.pk}/metadata?projection=EPSG:3857'
+        f'/api/rgd_imagery/tiles/{geotiff_image_entry.pk}/info/metadata?projection=EPSG:3857'
     )
     metadata = response.data
     assert metadata['levels'] == 15
@@ -25,7 +25,7 @@ def test_tile(admin_api_client, geotiff_image_entry):
 @pytest.mark.django_db(transaction=True)
 def test_thumbnail(admin_api_client, geotiff_image_entry):
     response = admin_api_client.get(
-        f'/api/rgd_imagery/tiles/{geotiff_image_entry.pk}/thumbnail.png'
+        f'/api/rgd_imagery/tiles/{geotiff_image_entry.pk}/data/thumbnail.png'
     )
     assert response.status_code == 200
     assert response['Content-Type'] == 'image/png'
